Method: Dataset::ContextClassMethods#datasets_directory
- Defined in:
- lib/dataset.rb
#datasets_directory(path) ⇒ Object
Replaces the default Dataset::Resolver with one that will look for dataset class definitions in the specified directory. Captures of the database will be stored in a subdirectory ‘tmp’ (see Dataset::Database::Base).
103 104 105 106 |
# File 'lib/dataset.rb', line 103 def datasets_directory(path) Dataset::Resolver.default = Dataset::DirectoryResolver.new(path) Dataset::ContextClassMethods.datasets_database_dump_path = File.join(path, '/tmp/dataset') end |